@@ -7,9 +7,12 @@ sub say{ print @_, "\n" }
 
 say neat "foo";
 say neat "here is a very long string";
+say neat \"bar";
 say neat 3.14;
 say neat 42;
+say neat \0xFF;
 say neat *foo;
+say neat \*foo;
 say neat \&foo;
 say neat [];
 say neat { foo => "bar" };
